<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>FacebookDepreceatedMessage</name>
    <message>
        <source>Facebook XMPP support is disabled since 01.05.2015. This means Kadu will be no longer able to connect to Facebook accounts. You can leave your Facebook accounts configured for chat history or you can remove them from Kadu using Your Account dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu - Facebook</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GTalkProtocolFactory</name>
    <message>
        <source>Gmail/Google Talk ID:</source>
        <translation>Identifient Gmail / Google Talk :</translation>
    </message>
</context>
<context>
    <name>JabberActions</name>
    <message>
        <source>Resend Subscription</source>
        <translation>Renvoyer l&apos;inscription</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Supprimer l&apos;inscription</translation>
    </message>
    <message>
        <source>Ask for Subscription</source>
        <translation>Demander l&apos;inscription</translation>
    </message>
</context>
<context>
    <name>JabberAddAccountWidget</name>
    <message>
        <source>&lt;a href=&apos;#&apos;&gt;What is my username?&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;#&apos;&gt;Quel est mon nom d&apos;utilisateur ?&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Sélectionner ou saisir l&apos;identifiant qui sera associé à votre compte.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Ajouter un compte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>JabberChangePassword</name>
    <message>
        <source>Current connection is not safe for password change. Use encrypted connection or change password on provider&apos;s site.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password change is not allowed.</source>
        <translation>Le changement de mot de passe n&apos;est pas autorisé.</translation>
    </message>
</context>
<context>
    <name>JabberChangePasswordWindow</name>
    <message>
        <source>Change Password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Nouveau mot de passe</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter new password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Saisir un nouveau mot de passe pour votre compte XMPP / Jabber.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Retype new password</source>
        <translation>Répéter un nouveau mot de passe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Changing password was successful.</source>
        <translation>Le mot de passe a été changé avec succès.</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;Password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Données saisies dans les champs requis non valides.

Mot de passes entrés dans les 2 champs(&quot;mot de passe&quot; et &quot;saisissez de nouveau votre mot de passe&quot;) doivent être les mêmes!</translation>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>S&apos;authentifier avant de changer le mot de passe.</translation>
    </message>
    <message>
        <source>Password change failed.

Error: %1</source>
        <translation>Échec du changement de mot de passe.

Erreur: %1</translation>
    </message>
</context>
<context>
    <name>JabberContactPersonalInfoWidget</name>
    <message>
        <source>Full Name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonyme</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
</context>
<context>
    <name>JabberCreateAccountWidget</name>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Retype Password</source>
        <translation>Répéter le mot de passe</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Sélectionner ou saisir l&apos;identifiant qui sera associé à ce compte.&lt;/i&gt;&lt;/font&gt;
</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Inscription de compte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;New password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Données invalides saisies dans les champs requis. ⏎ ⏎ Mot de passe entré dans les deux champs (&quot;Nouveau mot de passe&quot; et &quot;Confirmer mot de passe&quot;) doit être le même.</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Some servers require your e-mail address during registration.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Supprimer le compte</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Change your password</source>
        <translation>Changer votre mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Sélectionner ou saisisser l&apos;identifiant qui sera associé à votre compte.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Personal Information</source>
        <translation>Informations personnelles</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Toujours</translation>
    </message>
    <message>
        <source>When available</source>
        <translation>Lorsque disponible</translation>
    </message>
    <message>
        <source>Allow plaintext authentication</source>
        <translation>Autoriser l&apos;authentification en clair</translation>
    </message>
    <message>
        <source>Over encrypted connection</source>
        <translation>À travers une connexion cryptée</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Resource</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorité</translation>
    </message>
    <message>
        <source>Data transfer proxy</source>
        <translation>Proxy de transfert de données</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Supprimer un compte</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation>Configuration du proxy</translation>
    </message>
    <message>
        <source>Publish system information</source>
        <translation>Publier les informations système</translation>
    </message>
    <message>
        <source>XMPP Server</source>
        <translation>Serveur XMPP</translation>
    </message>
    <message>
        <source>Use custom server address/port</source>
        <translation>Utiliser une adresse/port personnalisé pour le serveur</translation>
    </message>
    <message>
        <source>Server address</source>
        <translation>Adresse Serveur</translation>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation>Utiliser une connexion cryptée</translation>
    </message>
    <message>
        <source>Only in older version</source>
        <translation>Seulement dans les anciennes versions</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau IM</translation>
    </message>
    <message>
        <source>Use computer name as a resource</source>
        <translation>Utiliser le nom de l&apos;hôte comme une ressource</translation>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation>Activer la génération d&apos;évènements</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation>Votre interlocuteur va être notifié quand vous composez un message, avant qu&apos;il soit envoyé et vice versa.</translation>
    </message>
    <message>
        <source>Enable chat activity events</source>
        <translation>Activer les évènements de conversation</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you suspend or end conversation. And vice versa.</source>
        <translation>Votre interlocuteur va être notifié lorsque vous suspendez ou terminez la conversation.</translation>
    </message>
    <message>
        <source>Others can see your system name/version</source>
        <translation>Les autres peuvent voir le nom/version de votre système</translation>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation>Confirmer la suppression du compte</translation>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation>Êtes vous certain de vouloir supprimer ce compte %1 (%2)</translation>
    </message>
    <message>
        <source>Require data transfer proxy:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>S&apos;authentifier avant de changer le mot de passe.</translation>
    </message>
</context>
<context>
    <name>JabberErrorService</name>
    <message>
        <source>Socket error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server did not respond for PING message</source>
        <translation>Le serveur n&apos;a pas répondu à la requête PING.</translation>
    </message>
    <message>
        <source>Unknown error: %1/%2</source>
        <translation>Erreur inconnu: %1/%2</translation>
    </message>
    <message>
        <source>Bad request</source>
        <translation>Mauvaise requête</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Conflit</translation>
    </message>
    <message>
        <source>Feature not implemented</source>
        <translation>Fonctionnalité non implémentée</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Interdit</translation>
    </message>
    <message>
        <source>Gone</source>
        <translation>Disparu</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Erreur interne du serveur</translation>
    </message>
    <message>
        <source>Item not found</source>
        <translation>Élément introuvable</translation>
    </message>
    <message>
        <source>Jid malformed</source>
        <translation>JID mal formé</translation>
    </message>
    <message>
        <source>Not acceptable</source>
        <translation>Inacceptable</translation>
    </message>
    <message>
        <source>Not allowed</source>
        <translation>Non autorisé</translation>
    </message>
    <message>
        <source>Not authorized</source>
        <translation>Non autorisé</translation>
    </message>
    <message>
        <source>Payment required</source>
        <translation>Paiement nécessaire</translation>
    </message>
    <message>
        <source>Recipient unavailable</source>
        <translation>Destinataire indisponible</translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation>Rediriger</translation>
    </message>
    <message>
        <source>Registration required</source>
        <translation>Inscription nécessaire</translation>
    </message>
    <message>
        <source>Remote server not found</source>
        <translation>Serveur distant introuvable</translation>
    </message>
    <message>
        <source>Remove server timeout</source>
        <translation>Délais de connexion dépassé au serveur distant</translation>
    </message>
    <message>
        <source>Resource constraint</source>
        <translation>Ressource restreinte</translation>
    </message>
    <message>
        <source>Service unavailable</source>
        <translation>Service indisponible</translation>
    </message>
    <message>
        <source>Subscription required</source>
        <translation>Inscription nécessaire</translation>
    </message>
    <message>
        <source>Undefined condition</source>
        <translation>Condition indéfinie</translation>
    </message>
    <message>
        <source>Unexpected request</source>
        <translation>Demande inattendue</translation>
    </message>
</context>
<context>
    <name>JabberOutgoingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>Interrompu</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Le fichier est corrompu</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Erreur de protocole</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnu</translation>
    </message>
</context>
<context>
    <name>JabberPersonalInfoWidget</name>
    <message>
        <source>Full name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
</context>
<context>
    <name>JabberProtocol</name>
    <message>
        <source>Another client connected on the same resource.</source>
        <translation>Un autre client est connecté avec la même ressource.</translation>
    </message>
</context>
<context>
    <name>JabberProtocolFactory</name>
    <message>
        <source>User JID:</source>
        <translation>Utilisateur JID :</translation>
    </message>
</context>
<context>
    <name>JabberRegisterAccount</name>
    <message>
        <source>Internal error: invalid state</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection established.</source>
        <translation>Connexion effectuée.</translation>
    </message>
    <message>
        <source>Negotiating registration parameters.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User with this username is already registered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration parameters received.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration at this server requires XMPP Data Forms support. Kadu currently does not support XMPP Data Forms.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1

Server message: %2</source>
        <translation>%1

Message serveur: %2</translation>
    </message>
    <message>
        <source>Unknown error: received stanza type %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSL certificate rejected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberStreamIncomingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>Interrompu</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Le Fichier est corrumpu</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Erreur de protocole</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnu</translation>
    </message>
</context>
<context>
    <name>JabberWaitForAccountRegisterWindow</name>
    <message>
        <source>Registration was successful. Your new XMPP username is %1.
Store it in a safe place along with the password.
Now please add your friends to the buddy list.</source>
        <translation>L&apos;inscription a réussie. Votre nouveau nom d&apos;utilisateur XMPP est %1.
Conservez le dans un endroit sûr avec son mot de passe.
Maintenant veuillez ajouter vos amis à la liste d&apos;amis.</translation>
    </message>
    <message>
        <source>Registering new XMPP account</source>
        <translation>Créer un compte XMPP sur le serveur</translation>
    </message>
    <message>
        <source>Registration failed.

Server message: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting with server.</source>
        <translation>Connexion au serveur.</translation>
    </message>
</context>
<context>
    <name>ShowXmlConsoleActionDescription</name>
    <message>
        <source>Show XML Console</source>
        <translation>Afficher la console XML</translation>
    </message>
</context>
<context>
    <name>XmlConsole</name>
    <message>
        <source>XML Console - %1</source>
        <translation>Console XML - %1</translation>
    </message>
</context>
</TS>